<div align="center"><p align="center">

# erte

[![npm version](https://badge.fury.io/js/erte.svg)](https://www.npmjs.com/package/erte)
<a href="https://gitlab.com/artdeco/erte/-/commits/master">
  <img src="https://gitlab.com/artdeco/erte/badges/master/pipeline.svg" alt="Pipeline Badge">
</a>
</p></div>

`erte` Colours Strings' Foreground And Background And Shows String Difference With Color.

```sh
yarn add erte
npm i erte
lud erte
```

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/0.svg">
</a></p></div>

## Table Of Contents

<a href="https://www.artd.eco"><img align="right" src="https://artdeco.gitlab.io/erte/woman.jpg" width="225" alt="erte" /></a>

- [Table Of Contents](#table-of-contents)
- [API](#api)
- [`erte(source: string, target: string): void`](#ertesource-stringtarget-string-void)
- [`c(string: string, color: Color, opts=: !Options): void`](#cstring-stringcolor-coloropts-options-void)
  * [`Color`](#type-color)
  * [`Options`](#type-options)
- [`b(string: string, color: Color, opts=: !Options): void`](#bstring-stringcolor-coloropts-options-void)
- [Copyright & License](#copyright--license)

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/1.svg">
</a></p></div>

## API

The package is available by importing its default and named functions:

```js
import erte, { c, b } from 'erte'
```

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/2.svg">
</a></p></div>

## <code><ins>erte</ins>(</code><sub><br/>&nbsp;&nbsp;`source: string,`<br/>&nbsp;&nbsp;`target: string,`<br/></sub><code>): <i>void</i></code>
Compares the strings using the [`diff`](https://www.npmjs.com/package/diff) package,
and outputs a coloured version where strings don't match with green or red differences.
Returns a string which uses shell-codes to highlight differences.

 - <kbd><strong>source*</strong></kbd> <em>`string`</em>: The string to compare.
 - <kbd><strong>target*</strong></kbd> <em>`string`</em>: The string to comparison against.

```js
import erte from 'erte'

const s = 'test this string'
const e = 'test this string with extra data'
const m = 'test this'

const green = erte(s, e)
console.log(green)

const red = erte(s, m)
console.log(red)

const grey = erte(s, s)
console.log(grey)
```
```
test this string with extra data
test this string
test this string
```

![extra](https://artdeco.gitlab.io/erte/extra.png)

![missing](https://artdeco.gitlab.io/erte/missing.png)

![same](https://artdeco.gitlab.io/erte/same.png)

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/3.svg">
</a></p></div>

## <code><ins>c</ins>(</code><sub><br/>&nbsp;&nbsp;`string: string,`<br/>&nbsp;&nbsp;`color: Color,`<br/>&nbsp;&nbsp;`opts=: !Options,`<br/></sub><code>): <i>void</i></code>
Colors the foreground using an ANSI sequence.

 - <kbd><strong>string*</strong></kbd> <em>`string`</em>: The string to color.
 - <kbd><strong>color*</strong></kbd> <em><code><a href="#type-color" title="The color to apply.">Color</a></code></em>: The color to use.
 - <kbd>opts</kbd> <em><code><a href="#type-options" title="Additional options.">!Options</a></code></em> (optional): Additional options.

Any text in strings can be coloured using the `c` and `b` methods. They accept a colour, and additional ANSI transformations.

<code>('black' \| 'red' \| 'green' \| 'yellow' \| 'blue' \| 'magenta' \| 'cyan' \| 'white' \| 'grey')</code> __<a name="type-color">`Color`</a>__: The color to apply.

__<a name="type-options">`Options`</a>__: Additional options.

|   Name    |       Type       |                       Description                        |
| --------- | ---------------- | -------------------------------------------------------- |
| bold      | <em>boolean</em> | The **bold** ANSI.                                       |
| underline | <em>boolean</em> | The ͟u͟n͟d͟e͟r͟l͟i͟n͟e͟ ANSI.                            |
| reverse   | <em>boolean</em> | The `reverse` ANSI (inverses background and foreground). |
| conceal   | <em>boolean</em> | The `conceal` ANSI (doesn't show symbols).               |

```js
import { c } from 'erte'

const redText = c('RED ALERT', 'red', {
  underline: true,
  bold: true,
  conceal: true,
  reverse: true,
})
console.log(redText)
```

![c](https://artdeco.gitlab.io/erte/c.png)

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/4.svg">
</a></p></div>

## <code><ins>b</ins>(</code><sub><br/>&nbsp;&nbsp;`string: string,`<br/>&nbsp;&nbsp;`color: Color,`<br/>&nbsp;&nbsp;`opts=: !Options,`<br/></sub><code>): <i>void</i></code>
Colors the background with specified ANSI color.

 - <kbd><strong>string*</strong></kbd> <em>`string`</em>: The string to color.
 - <kbd><strong>color*</strong></kbd> <em><code><a href="#type-color" title="The color to apply.">Color</a></code></em>: The color to use.
 - <kbd>opts</kbd> <em><code><a href="#type-options" title="Additional options.">!Options</a></code></em> (optional): Additional options.

```js
import { b } from 'erte'

const greenText = b('VEGAN', 'green')
console.log(greenText)
```

![b](https://artdeco.gitlab.io/erte/b.png)

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/5.svg">
</a></p></div>

## Copyright & License

The `diff` package is released under [BSD License](COPYING) by [Kevin Decker](https://github.com/kpdecker/jsdiff). [Artwork by Erte][3].

GNU Affero General Public License v3.0

<table>
  <tr>
    <th>
      <a href="https://www.artd.eco">
        <img width="100" src="https://gitlab.com/uploads/-/system/group/avatar/7454762/artdeco.png"
          alt="Art Deco">
      </a>
    </th>
    <th>© <a href="https://www.artd.eco">Art Deco™</a>   2020</th>
    <th>
      <a href="LICENSE"><img src="https://artdeco.gitlab.io/assets/licenses/agpl-3.0.svg" alt="AGPL-3.0"></a>
    </th>
  </tr>
</table>

[2]: https://www.npmjs.com/package/diff
[3]: http://www.erte.com

<div align="center"><p align="center"><a href="#table-of-contents">
  <img alt="section break" src="https://artdeco.gitlab.io/erte/section-breaks/-1.svg">
</a></p></div>