const { _erte, _c, _b } = require('./erte')

/**
 * Compares the strings using the [`diff`](https://www.npmjs.com/package/diff) package,
and outputs a coloured version where strings don't match with green or red differences.
Returns a string which uses shell-codes to highlight differences.
 * @param {string} source The string to compare.
 * @param {string} target The string to comparison against.
 * @return {string} String with diff parts shown in colour.
 */
function $erte(source, target) {
  return _erte(source, target)
}

/**
 * Colors the foreground using an ANSI sequence.
 * @param {string} string The string to color.
 * @param {Color} color The color to apply.
 * @param {!Options} [opts] Additional options. Only available in the paid version.
 * @param {boolean} [opts.bold] The **bold** ANSI.
 * @param {boolean} [opts.underline] The ͟u͟n͟d͟e͟r͟l͟i͟n͟e͟ ANSI.
 * @param {boolean} [opts.reverse] The `reverse` ANSI (inverses background and foreground).
 * @param {boolean} [opts.conceal] The `conceal` ANSI (doesn't show symbols).
 * @return {string} A string with text in colour.
 */
function $c(string, color, opts) {
  return _c(string, color, opts)
}

/**
 * Colors the background with specified ANSI color.
 * @param {string} string The string to color backgroud of.
 * @param {Color} color The color to apply.
 * @param {!Options} [opts] Additional options. Only available in the paid version.
 * @param {boolean} [opts.bold] The **bold** ANSI.
 * @param {boolean} [opts.underline] The ͟u͟n͟d͟e͟r͟l͟i͟n͟e͟ ANSI.
 * @param {boolean} [opts.reverse] The `reverse` ANSI (inverses background and foreground).
 * @param {boolean} [opts.conceal] The `conceal` ANSI (doesn't show symbols).
 * @return {string} A string with coloured background.
 */
function $b(string, color, opts) {
  return _b(string, color, opts)
}

module.exports = exports = $erte
module.exports.c = $c
module.exports.b = $b

/**
 * @typedef {$erte} erte
 * @typedef {$c} c
 * @typedef {$b} b
 */

/**
 * @typedef {('black'|'red'|'green'|'yellow'|'blue'|'magenta'|'cyan'|'white'|'grey')} Color The color to apply.
 */

/* typal types/index.xml ignore:_erte.Color */
/**
 * @typedef {Object} Options `＠record` Additional options. Only available in the paid version.
 * @prop {boolean} [bold] The **bold** ANSI.
 * @prop {boolean} [underline] The ͟u͟n͟d͟e͟r͟l͟i͟n͟e͟ ANSI.
 * @prop {boolean} [reverse] The `reverse` ANSI (inverses background and foreground).
 * @prop {boolean} [conceal] The `conceal` ANSI (doesn't show symbols).
 */
